# Class: exercise
# ===========================
#
# This module is a solution for TSE/PSE Exercise
#
# Parameters
# ----------
#
# wwwroot     - Defines the location of website's files. 
#               Required: no
#               Default: /var/www/html
#
# url         - Defines the FQDN of webstie. Must be reachable from the test machine. Also must be configured on the DNS or 
#               at least in the hosts file of the test machine. 
#               Required: yes
#               Example: ec2-52-63-123-244.ap-southeast-2.compute.amazonaws.com
#
# repository  - Defines the remote repository which stores the source code of the website. 
#               Required: no
#               Default: https://github.com/puppetlabs/exercise-webpage
#
# port        - Defines the port on which the website is reachable. 
#               Required: no
#               Default: 8000
# 
#
# Prerequisits
# ------------
#
# Requires SELinux to be disabled on Red Hat Enterprise because the port 8000 has
# already been defined for soundd_port_t
#
# Examples
# --------
#
# @examples
#   if $::operatingsystem == 'RedHat' {
#     class { '::selinux':
#       mode => 'disabled',
#     }
#   }    
#   class{"nginx": }
#   class { 'exercise': url => 'ec2-52-65-181-92.ap-southeast-2.compute.amazonaws.com' }
#
#
#
#   if $::operatingsystem == 'RedHat' {
#     class { '::selinux':
#       mode => 'disabled',
#     }
#   }    
#   class{"nginx": }
#   class { 'exercise': 
#     wwwroot     => '/var/www/html',
#     url         => 'ec2-52-63-123-244.ap-southeast-2.compute.amazonaws.com',
#     repository  => 'https://github.com/puppetlabs/exercise-webpage',
#     port        => 8000,
#    }  
#
# Authors
# -------
#
# Ivan Somodvarac <ivan@somodjvarac.com>
#
# Copyright
# ---------
#
# Copyright 2016 Ivan Somodvarac, unless otherwise noted.
#
class exercise ($wwwroot    = '/var/www/html', 
                $url, 
                $repository = 'https://github.com/puppetlabs/exercise-webpage', 
                $port       = 8000) {

  
  package {'git':
    ensure => present,
  }
  
  exec { "mkdir -p ${wwwroot}":
    creates => $wwwroot,
    path  => ['/usr/bin','/bin'],
  }  
  
  nginx::resource::vhost{"${url}":
    www_root    => $wwwroot,
    listen_port => $port, 
    require     => Vcsrepo[$wwwroot]
  }
    
  vcsrepo { "${wwwroot}":
    ensure    => present,
    provider  => git,
    source    => $repository,
    require   => [Package['git'], Exec["mkdir -p ${wwwroot}"]]
  }
}
